netapp_ontap.models.performance_reduced_throughput API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.performance_reduced_throughput`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PerformanceReducedThroughputSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PerformanceReducedThroughput object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: CollectionLinks GET`

    The links field of the performance_reduced_throughput.

  `num_records: Size GET POST PATCH`

    Number of records

    Example: 1

  `records: List[PerformanceMetricReducedThroughput] GET`

    Performance numbers, such as IOPS latency and throughput